<?php

namespace App\Console\Commands;

use App\Models\CarsEquipments;
use App\Models\EquipmentFieldsValues;
use App\Models\Servers;
use App\Sdk\Gelios;
use App\Sdk\WialonPro;
use Illuminate\Console\Command;

class LastTouch extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'last_touch';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Команда для обновления даты последнего выхода на связь оборудования';

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $this->info('Получаем список связок машина - оборудование');
        $car_equipments = CarsEquipments::all();

        $this->info('Начинаем проход циклом по полученному списку');
        $bar = $this->output->createProgressBar(count($car_equipments));

        foreach ($car_equipments as $car_equipment) {
            $server = $name = '';
            
            $fields = EquipmentFieldsValues::where('cars_equipments_id', $car_equipment->id)->get();
            foreach ($fields as $field) {
                if ((int) $field->equipment_fields_id === 1 && ! empty($field->value)) {
                    $server = Servers::find($field->value);
                }

                if ((int) $field->equipment_fields_id === 2) {
                    $name = $field->value;
                }
            }
            
            if (! $server || ! $name) {
                $this->error('Не удалось найти сервер или имя к связке #' . $car_equipment->id);
                continue;
            }

            if (empty($server->sdk_url) || empty($server->login) || empty($server->password)) {
                $this->error('Адрес, логин или пароль к sdk не найдены');
                continue;
            }

            switch ($server->type) {
                case 'wialon_pro':
                    $sdk = new WialonPro($server->sdk_url, $server->login, $server->password);
                    break;

                case 'gelios':
                    $sdk = new Gelios($server->sdk_url, $server->login, $server->password);
                    break;

                default:
                    $sdk = null;
                    break;
            }

            if ($sdk === null) {
                $this->error('SDK не создан');
                continue;
            }

            if (! $sdk->login()) {
                $this->error('Ошибка авторизации в SDK');
                continue;
            }

            $lastTouch = $sdk->getLastTouch($name);

            if (! empty($lastTouch)) {
                $car_equipment->last_touch = $lastTouch;
                $car_equipment->save();
            }

            $sdk->logout();
            unset($lastTouch, $sdk);
        }

        $bar->finish();
        $this->info('Выполнение команды завершено');
    }
}
