<?php

Route::group(['middleware' => 'web'], function()
{
    // Авторизация
    Route::get('/login', [
        'as' => 'login', 'uses' => 'Auth\AuthController@showLoginForm'
    ]);
    Route::post('/login', 'Auth\AuthController@login');

    // Выход
    Route::get('/logout', [
        'as' => 'logout', 'uses' => 'Auth\AuthController@logout'
    ]);

    Route::group(['middleware' => ['auth', 'acl'], 'is' => 'administrator|user'], function() {
        /* Работа с автомобилями */
        Route::group(['prefix' => 'cars'], function() {
            Route::pattern('car', '[0-9]+');
            Route::get('/', ['uses' => 'CarsController@lists', 'can' => 'view.cars']);
            Route::get('/add', ['uses' => 'CarsController@showFormAdd', 'can' => 'create.cars']);
            Route::post('/add', ['uses' => 'CarsController@create', 'can' => 'create.cars']);
            Route::get('/{car}', ['uses' => 'CarsController@view', 'can' => 'view.cars']);
            Route::get('/{car}/pdf', ['uses' => 'PdfController@viewPdf', 'can' => 'view.cars']);
            Route::get('/{car}/edit', ['uses' => 'CarsController@showFormUpdate', 'can' => 'update.cars']);
            Route::post('/{car}/edit', ['uses' => 'CarsController@update', 'can' => 'update.cars']);
            Route::get('/{car}/success', ['uses' => 'CarsController@success', 'can' => 'success.cars']);
            Route::get('/{car}/wanted', ['uses' => 'CarsController@wanted', 'can' => 'success.cars']);
            Route::get('/{car}/guarded', ['uses' => 'CarsController@guarded', 'can' => 'success.cars']);
            Route::get('/{car}/archive', ['uses' => 'CarsController@archive', 'can' => 'archive.cars']);
            Route::get('/{car}/monitoring', ['uses' => 'CarsController@monitoring', 'can' => 'delete.cars']);
            Route::get('/{car}/delete', ['uses' => 'CarsController@showFormDelete', 'can' => 'delete.cars']);
            Route::post('/{car}/delete', ['uses' => 'CarsController@delete', 'can' => 'delete.cars']);
            Route::delete('/{car}/photo_delete', ['uses' => 'CarsController@deletePhoto', 'can' => 'delete.cars']);

            Route::group(['prefix' => '/{car}/equipment'], function() {
                Route::pattern('equipments', '[0-9]+');
                Route::get('/', ['uses' => 'CarsEquipmentsController@showFormEquipment', 'can' => 'update.cars']);
                Route::post('/', ['uses' => 'CarsEquipmentsController@addEquipment', 'can' => 'update.cars']);
                Route::get('/{equipment}', ['uses' => 'CarsEquipmentsController@showFormUpdateEquipment', 'can' => 'update.cars']);
                Route::post('/{equipment}', ['uses' => 'CarsEquipmentsController@updateEquipment', 'can' => 'update.cars']);
                Route::get('/{equipment}/delete', ['uses' => 'CarsEquipmentsController@showFormDeleteEquipment', 'can' => 'update.cars']);
                Route::post('/{equipment}/delete', ['uses' => 'CarsEquipmentsController@deleteEquipment', 'can' => 'update.cars']);
            });
        });

        /* Работа с пользователями */
        Route::group(['prefix' => 'users'], function() {
            Route::pattern('user', '[0-9]+');
            Route::get('/', ['uses' => 'UsersController@lists', 'can' => 'view.users']);
            Route::get('/add', ['uses' => 'UsersController@showFormAdd', 'can' => 'create.users']);
            Route::post('/add', ['uses' => 'UsersController@create', 'can' => 'create.users']);
            Route::get('/{user}', ['uses' => 'UsersController@view', 'can' => 'view.users']);
            Route::get('/{user}/edit', ['uses' => 'UsersController@showFormUpdate', 'can' => 'update.users']);
            Route::post('/{user}/edit', ['uses' => 'UsersController@update', 'can' => 'update.users']);
            Route::get('/{user}/password', ['uses' => 'UsersController@showFormPassword', 'is' => 'administrator']);
            Route::post('/{user}/password', ['uses' => 'UsersController@updatePassword', 'is' => 'administrator']);
            Route::get('/{user}/delete', ['uses' => 'UsersController@showFormDelete', 'can' => 'delete.users']);
            Route::post('/{user}/delete', ['uses' => 'UsersController@delete', 'can' => 'delete.users']);
            Route::get('/{user}/open-hidden', ['uses' => 'UsersController@openHidden', 'can' => 'delete.users']);
            Route::get('/{user}/close-hidden', ['uses' => 'UsersController@closeHidden', 'can' => 'delete.users']);
        });

        /* Работа с серверами */
        Route::group(['prefix' => 'servers'], function() {
            Route::pattern('server', '[0-9]+');
            Route::get('/', ['uses' => 'ServersController@lists', 'can' => 'view.servers']);
            Route::get('/add', ['uses' => 'ServersController@showFormAdd', 'can' => 'create.servers']);
            Route::post('/add', ['uses' => 'ServersController@create', 'can' => 'create.servers']);
            Route::get('/{server}', ['uses' => 'ServersController@view', 'can' => 'view.servers']);
            Route::get('/{server}/edit', ['uses' => 'ServersController@showFormUpdate', 'can' => 'update.servers']);
            Route::post('/{server}/edit', ['uses' => 'ServersController@update', 'can' => 'update.servers']);
            Route::get('/{server}/delete', ['uses' => 'ServersController@showFormDelete', 'can' => 'delete.servers']);
            Route::post('/{server}/delete', ['uses' => 'ServersController@delete', 'can' => 'delete.servers']);
        });

        /* Работа с оборудованием */
        Route::group(['prefix' => 'equipments'], function() {
            Route::pattern('equipment', '[0-9]+');
            Route::get('/', ['uses' => 'EquipmentsController@lists', 'can' => 'view.equipments']);
            Route::post('/fields', ['uses' => 'FieldsController@loadFields', 'can' => 'update.cars']);
            Route::get('/add', ['uses' => 'EquipmentsController@showFormAdd', 'can' => 'create.equipments']);
            Route::post('/add', ['uses' => 'EquipmentsController@create', 'can' => 'create.equipments']);
            Route::get('/{equipment}', ['uses' => 'EquipmentsController@view', 'can' => 'view.equipments']);
            Route::get('/{equipment}/edit', ['uses' => 'EquipmentsController@showFormUpdate', 'can' => 'update.equipments']);
            Route::post('/{equipment}/edit', ['uses' => 'EquipmentsController@update', 'can' => 'update.equipments']);
            Route::get('/{equipment}/delete', ['uses' => 'EquipmentsController@showFormDelete', 'can' => 'delete.equipments']);
            Route::post('/{equipment}/delete', ['uses' => 'EquipmentsController@delete', 'can' => 'delete.equipments']);

            Route::group(['prefix' => '/{equipment}/fields'], function() {
                Route::pattern('field', '[0-9]+');
                Route::get('/add', ['uses' => 'FieldsController@showFormAdd', 'can' => 'create.equipments']);
                Route::post('/add', ['uses' => 'FieldsController@create', 'can' => 'create.equipments']);
                Route::get('/{field}/edit', ['uses' => 'FieldsController@showFormUpdate', 'can' => 'update.equipments']);
                Route::post('/{field}/edit', ['uses' => 'FieldsController@update', 'can' => 'update.equipments']);
                Route::get('/{field}/delete', ['uses' => 'FieldsController@showFormDelete', 'can' => 'delete.equipments']);
                Route::post('/{field}/delete', ['uses' => 'FieldsController@delete', 'can' => 'delete.equipments']);
            });

            Route::group(['prefix' => '/markers'], function() {
                Route::post('/delete', ['uses' => 'FieldsController@deleteMarker', 'can' => 'delete.equipments']);
            });

            Route::group(['prefix' => '/{equipment}/commands'], function() {
                Route::pattern('command', '[0-9]+');
                Route::get('/add', ['uses' => 'CommandsController@showFormAdd', 'can' => 'create.equipments']);
                Route::post('/add', ['uses' => 'CommandsController@create', 'can' => 'create.equipments']);
                Route::get('/{command}/edit', ['uses' => 'CommandsController@showFormUpdate', 'can' => 'update.equipments']);
                Route::post('/{command}/edit', ['uses' => 'CommandsController@update', 'can' => 'update.equipments']);
                Route::get('/{command}/delete', ['uses' => 'CommandsController@showFormDelete', 'can' => 'delete.equipments']);
                Route::post('/{command}/delete', ['uses' => 'CommandsController@delete', 'can' => 'delete.equipments']);
            });
        });

        /* Работа с клиентами */
        Route::group(['prefix' => 'clients'], function() {
            Route::pattern('client', '[0-9]+');
            Route::get('/', 'ClientsController@getList');
            Route::post('/', 'ClientsController@Search');
            Route::get('/add', 'ClientsController@showFormAdd');
            Route::post('/add', 'ClientsController@Create');
            Route::post('/ajax', 'ClientsController@CreateAjax');
            Route::get('/{client}', 'ClientsController@getById');
            Route::get('/{client}/edit', 'ClientsController@showFormUpdate');
            Route::post('/{client}/edit', 'ClientsController@Update');
            Route::post('/{client}/delete', 'ClientsController@Delete');
            Route::post('/{client}/debtor', 'ClientsController@Debtor');
            Route::post('/{client}/active', 'ClientsController@Active');
            Route::post('/{client}/fraud', 'ClientsController@Fraud');
            Route::delete('/contact/delete', 'ClientsController@deleteContact');

            Route::group(['prefix' => '/fields'], function() {
                Route::pattern('field', '[0-9]+');
                Route::get('/', 'ClientsFieldsController@getList');
                Route::post('/', 'ClientsFieldsController@loadFields');
                Route::get('/add', 'ClientsFieldsController@showFormAdd');
                Route::post('/add', 'ClientsFieldsController@Create');
                Route::get('/{field}/edit', 'ClientsFieldsController@showFormUpdate');
                Route::post('/{field}/edit', 'ClientsFieldsController@Update');
                Route::post('/{field}/delete', 'ClientsFieldsController@Delete');
            });
        });
    });

    // Главная страница
    Route::get('/', function () {
        return redirect('/cars');
    });

    // Просмотр документации
    Route::get('/docs/{page?}', 'DocsController@show');
});