<?php

namespace RachidLaasri\LaravelInstaller\Helpers;

use Exception;
use Illuminate\Http\Request;

class EnvironmentManager
{
    /**
     * @var string
     */
    private $envPath;

    /**
     * @var string
     */
    private $envExamplePath;

    /**
     * Set the .env and .env.example paths.
     */
    public function __construct()
    {
        $this->envPath = base_path('.env');
        $this->envExamplePath = base_path('.env.example');
    }

    /**
     * Get the content of the .env file.
     *
     * @return string
     */
    public function getEnvContent()
    {
        if (!file_exists($this->envPath)) {
            if (file_exists($this->envExamplePath)) {
                copy($this->envExamplePath, $this->envPath);
            } else {
                touch($this->envPath);
            }
        }

        return file_get_contents($this->envPath);
    }

    /**
     * Save the edited content to the file.
     *
     * @param Request $input
     * @return string
     */
    public function saveFile(Request $input)
    {
        $message = trans('installer_messages.environment.success');

        try {
            $envFile = $this->getEnvContent();

            $envFile = str_replace('LICENSE_KEY=' . env('LICENSE_KEY'), 'LICENSE_KEY=' . $input->get('license_key', ''), $envFile);
            $envFile = str_replace('DB_HOST=' . env('DB_HOST'), 'DB_HOST=' . $input->get('db_host', ''), $envFile);
            $envFile = str_replace('DB_DATABASE=' . env('DB_DATABASE'), 'DB_DATABASE=' . $input->get('db_name', ''), $envFile);
            $envFile = str_replace('DB_USERNAME=' . env('DB_USERNAME'), 'DB_USERNAME=' . $input->get('db_user', ''), $envFile);
            $envFile = str_replace('DB_PASSWORD=' . env('DB_PASSWORD'), 'DB_PASSWORD=' . $input->get('db_pass', ''), $envFile);
            $envFile = str_replace('MAIL_HOST=' . env('MAIL_HOST'), 'MAIL_HOST=' . $input->get('smtp_host', ''), $envFile);
            $envFile = str_replace('MAIL_PORT=' . env('MAIL_PORT'), 'MAIL_PORT=' . $input->get('smtp_port', ''), $envFile);
            $envFile = str_replace('MAIL_USERNAME=' . env('MAIL_USERNAME'), 'MAIL_USERNAME=' . $input->get('smtp_user', ''), $envFile);
            $envFile = str_replace('MAIL_PASSWORD=' . env('MAIL_PASSWORD'), 'MAIL_PASSWORD=' . $input->get('smtp_pass', ''), $envFile);
            $envFile = str_replace('MAIL_ENCRYPTION=' . env('MAIL_ENCRYPTION'), 'MAIL_ENCRYPTION=' . $input->get('smtp_enc', ''), $envFile);

            file_put_contents($this->envPath, $envFile);
        }
        catch(Exception $e) {
            $message = trans('installer_messages.environment.errors');
        }

        return $message;
    }
}